GetForm: Get form metadata and field structure.

View source: R/GetForm.R

GetFormR Documentation

Get form metadata and field structure.

Description

Retrieves the metadata and complete component (field) structure of a specific form. This function replaces the former GetFormStructure.

Usage

GetForm(token, idForm, nameForm = NULL)

Arguments

token

A string access token.

idForm

Numeric Id of the required form.

nameForm

String name of the required form. Used only when idForm is not supplied. When this parameter is used, one extra access quota is spent.

Details

To get more details about the fields provided by the result, please visit the API documentation.

Value

A list with elements: id, name, description, status, category, version, public_answers, and components (a nested data frame representing the form's field schema, where each row is a component with columns id, type, label, help_block, maximum, minimum, visibility, and — for group components — components).

Examples


GetForm("cizio7xeohwgc8k4g4koo008kkoocwg", 5705)
GetForm("cizio7xeohwgc8k4g4koo008kkoocwg", nameForm = "RColetum Test - Iris")
GetForm(token = "cizio7xeohwgc8k4g4koo008kkoocwg",
        nameForm = "RColetum Test - Iris")


RColetum documentation built on April 17, 2026, 1:07 a.m.