Learn R Programming

RColetum (version 0.2.2)

RColetum-package: RColetum

Description

An R package to get data from Coletum.

Arguments

<span class="pkg">RColetum</span> functions

The currents functions that are provide by RColetum are:

  • GetForms: get the information about all forms.

  • GetFormStructure: get the form structure of a form.

  • GetAnswers: get the all the answers of a form or personalize with filters and take just what you need.

Author

Maintainer: André Smaniotto smaniotto@geosapiens.com.br

Authors:

Other contributors:

  • GeoSapiens [copyright holder, funder]

See Also