| GetForm | R Documentation |
Retrieves the metadata and complete component (field) structure of a
specific form. This function replaces the former GetFormStructure.
GetForm(token, idForm, nameForm = NULL)
token |
A string access token. |
idForm |
Numeric Id of the required form. |
nameForm |
String name of the required form. Used only when
|
To get more details about the fields provided by the result, please visit the API documentation.
A list with elements: id, name, description,
status, category, version, public_answers,
and components (a nested data frame representing the form's field
schema, where each row is a component with columns id,
type, label, help_block, maximum,
minimum, visibility, and — for group components —
components).
GetForm("cizio7xeohwgc8k4g4koo008kkoocwg", 5705)
GetForm("cizio7xeohwgc8k4g4koo008kkoocwg", nameForm = "RColetum Test - Iris")
GetForm(token = "cizio7xeohwgc8k4g4koo008kkoocwg",
nameForm = "RColetum Test - Iris")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.